==> nextcloud-23.0.3.tgz: nextcloud/apps/theming/l10n/ja.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "プレビューを読み込み中...",
    "Saved" : "保存済み",
    "Admin" : "管理者",
    "a safe home for all your data" : "あなたのすべてのデータを安全に保管する場所",
    "Name cannot be empty" : "名前は空にできません",
    "The given name is too long" : "名前が長すぎます",
    "The given web address is too long" : "Webアドレスが長すぎます",
    "The given web address is not a valid URL" : "指定されたWebアドレスは有効なURLではありません",
    "The given legal notice address is too long" : "指定された法的通知アドレスが長すぎます",
    "The given legal notice address is not a valid URL" : "指定された法的通知アドレスは有効なURLではありません",
    "The given privacy policy address is too long" : "指定された個人情報保護方針のアドレスが長すぎます",
    "The given privacy policy address is not a valid URL" : "指定された個人情報保護方針アドレスは有効なURLではありません",
    "The given slogan is too long" : "スローガンが長すぎます",
    "The given color is invalid" : "無効な色です",
    "The file was uploaded" : "ファイルがアップロードされました",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードファイルサイズが、php.ini の upload_max_filesize を超過しています",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードファイルはHTMLフォームで指定された MAX_FILE_SIZE の制限を超えています",
    "The file was only partially uploaded" : "ファイルは一部分にしかアップロードされていません",
    "No file was uploaded" : "ファイルはアップロードされませんでした",
    "Missing a temporary folder" : "一時領域フォルダーがありません",
    "Could not write file to disk" : "ディスクにファイルを書き込めませんでした",
    "A PHP extension stopped the file upload" : "PHP拡張でファイルのアップロードが停止されています",
    "No file uploaded" : "ファイルがアップロードされていません",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "あなたはすでにカスタムテーマを使用しています。 テーマ設定の設定が上書きされる可能性があります。",
    "Theming" : "テーマ",
    "Legal notice" : "法的通知",
    "Privacy policy" : "個人情報保護方針",
    "Adjust the Nextcloud theme" : "Nextcloudテーマを調整する",
    "Open documentation" : "ドキュメントを開く",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "テーマでは、あなたのインスタンスとサポートされたクライアントのルック＆フィールを簡単に変更できます。この変更はすべてのユーザーが対象となります。",
    "Name" : "名前",
    "Reset to default" : "デフォルトに戻す",
    "Web link" : "Webリンク",
    "https://…" : "https://…",
    "Slogan" : "標語",
    "Color" : "色",
    "Logo" : "ロゴ",
    "Upload new logo" : "新しいロゴをアップロード",
    "Login image" : "ログイン画像",
    "Upload new login background" : "新しいログイン背景画像をアップロード",
    "Remove background image" : "背景画像を削除",
    "Advanced options" : "詳細オプション",
    "Legal notice link" : "法的通知のリンク",
    "Privacy policy link" : "個人情報保護方針のリンク",
    "Header logo" : "ヘッダーロゴ",
    "Upload new header logo" : "新しいヘッダーロゴをアップロード",
    "Favicon" : "Favicon",
    "Upload new favicon" : "新しいfaviconをアップロード",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "アップロードしたロゴと色に基づいてfaviconを自動的に生成するには、SVG画像をサポートしているimagemagick PHP拡張をインストールしてください。"
},
"nplurals=1; plural=0;");

==> nextcloud-23.0.9.tgz: nextcloud/apps/theming/l10n/ja.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "プレビューを読み込み中...",
    "Admin" : "管理者",
    "Saved" : "保存済み",
    "a safe home for all your data" : "あなたのすべてのデータを安全に保管する場所",
    "Name cannot be empty" : "名前は空にできません",
    "The given name is too long" : "名前が長すぎます",
    "The given web address is too long" : "Webアドレスが長すぎます",
    "The given web address is not a valid URL" : "指定されたWebアドレスは有効なURLではありません",
    "The given legal notice address is too long" : "指定された法的通知アドレスが長すぎます",
    "The given legal notice address is not a valid URL" : "指定された法的通知アドレスは有効なURLではありません",
    "The given privacy policy address is too long" : "指定された個人情報保護方針のアドレスが長すぎます",
    "The given privacy policy address is not a valid URL" : "指定された個人情報保護方針アドレスは有効なURLではありません",
    "The given slogan is too long" : "スローガンが長すぎます",
    "The given color is invalid" : "無効な色です",
    "The file was uploaded" : "ファイルがアップロードされました",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードファイルサイズが、php.ini の upload_max_filesize を超過しています",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードファイルはHTMLフォームで指定された MAX_FILE_SIZE の制限を超えています",
    "The file was only partially uploaded" : "ファイルは一部分にしかアップロードされていません",
    "No file was uploaded" : "ファイルはアップロードされませんでした",
    "Missing a temporary folder" : "一時領域フォルダーがありません",
    "Could not write file to disk" : "ディスクにファイルを書き込めませんでした",
    "A PHP extension stopped the file upload" : "PHP拡張でファイルのアップロードが停止されています",
    "No file uploaded" : "ファイルがアップロードされていません",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "あなたはすでにカスタムテーマを使用しています。 テーマ設定の設定が上書きされる可能性があります。",
    "Theming" : "テーマ",
    "Dark theme" : "ダークテーマ",
    "Enable dark theme" : "ダークテーマを有効にする",
    "Dyslexia font" : "Dyslexia フォント",
    "Enable dyslexia font" : "Dyslexia フォントを有効にする",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexicは、ディスレクシアによって引き起こされる一般的な読み間違いの一部を軽減するためにデザインされた、無料で利用できる書体/フォントです。",
    "High contrast mode" : "ハイ・コントラストモード",
    "Enable high contrast mode" : "ハイ・コントラストモードを有効にする。",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "操作をわかりやすくするためのハイ・コントラストモード。\n見た目の美しさは低下しますが、明確さが向上します。",
    "Legal notice" : "法的通知",
    "Privacy policy" : "個人情報保護方針",
    "Adjust the Nextcloud theme" : "Nextcloudテーマを調整する",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "ユニバーサルアクセスは私たちにとって非常に重要なことです。そのためウェブ標準に従い、マウスやスクリーンリーダーなどの支援ソフトウェアが無くても全ての機能をご利用いただけるようにチェックしています。AAAレベルのハイコントラストのテーマを採用することで、{guidelines} Webコンテンツアクセシビリティガイドライン2.1  {linkend} のAAAレベルに準拠することを目指しています。",
    "Open documentation" : "ドキュメントを開く",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "テーマでは、あなたのインスタンスとサポートされたクライアントのルック＆フィールを簡単に変更できます。この変更はすべてのユーザーが対象となります。",
    "Name" : "名前",
    "Reset to default" : "デフォルトに戻す",
    "Web link" : "Webリンク",
    "https://…" : "https://…",
    "Slogan" : "標語",
    "Color" : "色",
    "Logo" : "ロゴ",
    "Upload new logo" : "新しいロゴをアップロード",
    "Login image" : "ログイン画像",
    "Upload new login background" : "新しいログイン背景画像をアップロード",
    "Remove background image" : "背景画像を削除",
    "Advanced options" : "詳細オプション",
    "Legal notice link" : "法的通知のリンク",
    "Privacy policy link" : "個人情報保護方針のリンク",
    "Header logo" : "ヘッダーロゴ",
    "Upload new header logo" : "新しいヘッダーロゴをアップロード",
    "Favicon" : "Favicon",
    "Upload new favicon" : "新しいfaviconをアップロード",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "アップロードしたロゴと色に基づいてfaviconを自動的に生成するには、SVG画像をサポートしているimagemagick PHP拡張をインストールしてください。"
},
"nplurals=1; plural=0;");
